import 'package:puissance4/config/default_game_settings.dart';
import 'package:puissance4/utils/tools.dart';

class GameSettings {
  final String gameMode;
  final String size;

  GameSettings({
    required this.gameMode,
    required this.size,
  });

  static String getGameModeValueFromUnsafe(String gameMode) {
    if (DefaultGameSettings.allowedGameModeValues.contains(gameMode)) {
      return gameMode;
    }

    return DefaultGameSettings.defaultGameModeValue;
  }

  static String getSizeValueFromUnsafe(String size) {
    if (DefaultGameSettings.allowedSizeValues.contains(size)) {
      return size;
    }

    return DefaultGameSettings.defaultSizeValue;
  }

  factory GameSettings.createDefault() {
    return GameSettings(
      gameMode: DefaultGameSettings.defaultGameModeValue,
      size: DefaultGameSettings.defaultSizeValue,
    );
  }

  void dump() {
    printlog('$GameSettings:');
    printlog('  ${DefaultGameSettings.parameterCodeGameMode}: $gameMode');
    printlog('  ${DefaultGameSettings.parameterCodeSize}: $size');
    printlog('');
  }

  @override
  String toString() {
    return '$GameSettings(${toJson()})';
  }

  Map<String, dynamic>? toJson() {
    return <String, dynamic>{
      DefaultGameSettings.parameterCodeGameMode: gameMode,
      DefaultGameSettings.parameterCodeSize: size,
    };
  }
}
