import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

import 'package:puissance4/cubit/game_cubit.dart';
import 'package:puissance4/ui/helpers/styled_button.dart';

class GameBoardWidget extends StatelessWidget {
  const GameBoardWidget({super.key});

  @override
  Widget build(BuildContext context) {
    return Center(
      child: BlocBuilder<GameCubit, GameState>(
        builder: (BuildContext context, GameState gameState) {
          final Color borderColor = Theme.of(context).colorScheme.onSurface;

          Widget cellContent({required int row, required int col}) {
            final cellValue = gameState.currentGame.board.getCellValue(row: row, col: col);
            final Color color =
                cellValue == 0 ? Colors.grey : (cellValue == 1 ? Colors.yellow : Colors.red);

            return AspectRatio(
              aspectRatio: 1,
              child: StyledButton(
                color: color,
                onPressed: () {
                  BlocProvider.of<GameCubit>(context).tapOnColumn(col: col);
                },
                child: SizedBox.shrink(),
              ),
            );
          }

          return Container(
            margin: const EdgeInsets.all(2),
            padding: const EdgeInsets.all(2),
            decoration: BoxDecoration(
              color: borderColor,
              borderRadius: BorderRadius.circular(8),
              border: Border.all(
                color: borderColor,
                width: 2,
              ),
            ),
            child: Table(
              defaultColumnWidth: const IntrinsicColumnWidth(),
              children: [
                for (int row = 0; row < gameState.currentGame.sizeVertical; row++)
                  TableRow(
                    children: [
                      for (int col = 0; col < gameState.currentGame.sizeHorizontal; col++)
                        Column(
                          children: [cellContent(row: row, col: col)],
                        ),
                    ],
                  ),
              ],
            ),
          );
        },
      ),
    );
  }
}
